@@ -13,7 +13,6 @@ static const R_CMethodDef Centries[] = {
     {"Cagfit5a",    (DL_FUNC) &agfit5a,  21},
     {"Cagfit5b",    (DL_FUNC) &agfit5b,  19},
     {"Cagfit5c",    (DL_FUNC) &agfit5c,   1},
-    {"Cagsurv3",    (DL_FUNC) &agsurv3,   19},
     {"Cagsurv4",    (DL_FUNC) &agsurv4,    6},
     {"Cagsurv5",    (DL_FUNC) &agsurv5,   10},
     {"Cagexact",    (DL_FUNC) &agexact,   21},
@@ -50,8 +49,10 @@ static const R_CallMethodDef Callentries[] = {
     {"Ccoxexact",     (DL_FUNC) &coxexact,     8},
     {"Ccoxfit6",      (DL_FUNC) &coxfit6,     12},
     {"Ccoxscore2",    (DL_FUNC) &coxscore2,    6},
-    {"Ccoxsurv1",     (DL_FUNC) &coxsurv1,    11},
+    {"Ccoxsurv1",     (DL_FUNC) &coxsurv1,     7},
     {"Ccoxsurv2",     (DL_FUNC) &coxsurv2,     9},
+    {"Cfastkm1",      (DL_FUNC) &fastkm1,      3},
+    {"Cfastkm2",      (DL_FUNC) &fastkm1,      4},
     {"Cfinegray",     (DL_FUNC) &finegray,     6},
     {"Cgchol",        (DL_FUNC) &gchol,        2},
     {"Cgchol_solve",  (DL_FUNC) &gchol_solve,  3},
