@@ -8,7 +8,8 @@ library(survival)
 test1 <- data.frame(time=  c(9, 3,1,1,6,6,8),
                     status=c(1,NA,1,0,1,1,0),
                     x=     c(0, 2,1,1,1,0,0),
-                    z= factor(c('a', 'a', 'b', 'b', 'c', 'c', 'a')))
+                    z= factor(c('a', 'a', 'b', 'b', 'c', 'c', 'a')),
+                    stringsAsFactors=FALSE)
 
 fit1 <- coxph(Surv(time, status) ~ z, test1, iter=1)
 fit2 <- coxph(Surv(time, status) ~z, test1, x=T, iter=1)
@@ -18,7 +19,8 @@ all.equal(model.matrix(fit1), fit2$x)
 test2 <- data.frame(time=  c(9, 3,1,1,6,6,8),
                     status=c(1,NA,1,0,1,1,0),
                     x=     c(0, 2,1,1,1,0,0),
-                    z= factor(c('a', 'a', 'a', 'a', 'c', 'c', 'a')))
+                    z= factor(c('a', 'a', 'a', 'a', 'c', 'c', 'a')),
+                    stringsAsFactors=FALSE)
 
 ftest <- model.frame(fit1, data=test2)
 all.equal(levels(ftest$z), levels(test1$z))
