@@ -21,3 +21,13 @@ x <- time2 -time1
 
 fit1 <- survfit(Surv(x) ~1)
 length(fit1$time) == length(fit1$surv)
+
+
+# a second test, once "rounding.R"
+
+tdata <- data.frame(time=c(1,2, sqrt(2)^2, 2, sqrt(2)^2),
+                    status=rep(1,5), 
+                    group=c(1,1,1,2,2))
+fit <- survfit(Surv(time, status) ~ group, data=tdata)
+
+all.equal(sum(fit$strata), length(fit$time))
